@@ -259,7 +259,8 @@ class RepoGit:
 
     # 提交代码
     def commit(self, msg):
-        self.repo.index.commit(msg)
+        # self.repo.index.commit(msg)
+        self.repo.git.commit(m=msg)
 
     def add(self, files):
         self.repo.git.add(all=True)
@@ -420,7 +421,8 @@ def update_module_files(yaml_path, local_yaml_path, branch_result, n_branch, mod
     for a in conver_deplist:
         for mo_re in branch_result:
             if a.module and mo_re.module and a.module == mo_re.module and mo_re.result == 1:
-                module_dict = {"module": mo_re.module, "pod": a.pod, "git": a.git, "branch": n_branch, "configurations": a.configurations,
+                module_dict = {"module": mo_re.module, "pod": a.pod, "git": a.git, "branch": n_branch,
+                               "configurations": a.configurations,
                                "inhibit_warnings": a.inhibit_warnings}
                 dependenceList[index] = module_dict
         index += 1
@@ -496,80 +498,6 @@ def merge_for_module_files(yaml_path, branch_result, n_branch):
     update_yaml(yaml_path, podfile_data)
 
 
-# 基于master 和 f_tag，创建一个新的分支new_branch, 如果文件目录存在，则判断当前是否在dui'y
-# 1. 清空当前工作目录
-# 2. 拉取代码
-# 3. 新建分支
-# 4. 推送分支
-# 5. 提交代码
-def auto_push_branch(filepath, git, f_branch, f_tag, n_branch):
-    """
-    将代码提交到n_branch
-    1. 如果本地没有组件对应目录，异常提示错误
-    2. 存在目录：在当前新分支，直接提交代码，
-    3. 存在目录：本地不在新分支，异常提示错误
-    :param filepath: 路径
-    :param git: git地址
-    :param f_branch: 基于哪个分支切一个新的开发分支
-    :param f_tag:  基于哪个tag切开发分支
-    :param n_branch: 新分支名
-    :return: 成功返回新分支名，失败返回空字符串
-    """
-    (file, ext) = os.path.splitext(git)
-    (path, filename) = os.path.split(git)
-    module_name = filename.replace(ext, "")
-    _branch = f_branch
-    if not (f_branch and len(f_branch) > 0):
-        _branch = "master"
-    # 创建分支
-    print(os.getcwd())
-    fapath = os.getcwd()
-    if os.path.exists(filepath):
-        # 存在目录，判断当前处于哪个分支下
-        try:
-            repo = Repo(path=filepath, search_parent_directories=True)
-        except:
-            br = new_branch(filepath, git, _branch, f_tag, n_branch)
-            return br
-        c_branch = repo.active_branch.name
-        # 判断当前分支是不是是指定的开发分支
-        if c_branch == f_branch:
-            # git add 代码
-            git_add_command = "git add -A"
-            # git commit 代码
-            git_commit_command = "git commit -m \'自动提交\'"
-            # git pull branch 代码
-            git_pull_command = "git pull origin " + c_branch
-            # git push
-            git_push_command = "git push origin master"
-            os.chdir(filepath)
-            os.system(git_add_command)
-            logging.info("执行 " + git_add_command)
-            os.system(git_commit_command)
-            logging.info("执行 " + git_commit_command)
-            pul_status = os.system(git_pull_command)
-            if not pul_status == 0:
-                os.chdir(fapath)
-                logging.error("模块：" + module_name + " 分支: " + f_branch + " 提交失败")
-                return ""
-            pul_status += os.system(git_push_command)
-            if not pul_status == 0:
-                os.chdir(fapath)
-                logging.error("模块：" + module_name + " 分支: " + f_branch + " 提交失败")
-                return ""
-
-            os.chdir(fapath)
-            return n_branch
-        else:
-            logging.error("模块：" + module_name + " 分支: " + c_branch + " 不在开发分支提交不了")
-            return ""
-
-        return n_branch
-    else:
-        logging.error("模块：" + module_name + "分支: " + f_branch + " 本地没有组件的工作目录，没法自动提交代码")
-        return ""
-
-
 # 自动打tag 自动合并失败时返回空字符串
 # 1. 清空当前工作目录
 # 2. 拉取代码
@@ -654,47 +582,6 @@ def auto_release_path(filepath, git, pod, branch, new_tag):
     return new_tag_p
 
 
-# 基于主项目分支切一个新的分支
-def checkout_project(filepath, git, c_branch, c_tag, n_branch):
-    """
-    基于c_branch和c_tag，新建一个分支n_branch
-    :param filepath: 主项目本地目录
-    :param git: git地址
-    :param c_branch: 基于哪个分支切开发分支
-    :param c_tag: 基于哪个tag切开发分支
-    :param n_branch: 新分支名
-    :return:
-    """
-    # return
-    # 进入模块
-    # clone 代码
-    c_branch = c_branch
-    if not (c_branch and len(c_branch) > 0):
-        c_branch = "master"
-
-    git_clone_command = "git clone -b " + c_branch + " " + git + " " + filepath
-    # remote add origin
-    git_remote_origin = "git remote add  origin " + git
-    # 创建一个新分支
-    git_create_branch = "git branch " + n_branch
-    if c_tag and len(c_tag) > 0:
-        git_create_branch += c_tag
-    # checkout
-    git_checkout_command = "git checkout " + n_branch
-    # 推送分支
-    git_push_branch = "git push origin " + n_branch
-    logging.info(git_clone_command)
-    # Repo.clone_from(git, to_path=filepath, branch=c_branch)
-    # os.chdir(filepath)
-    clone_status = os.system(git_clone_command)
-    clone_status += os.system(git_remote_origin)
-    logging.info(clone_status)
-    os.system(git_create_branch)
-    os.system(git_checkout_command)
-    os.system(git_push_branch)
-    logging.info("壳工程目录：" + filepath)
-
-
 # 基于podfileModule来给每个组件创建一个分支
 def create_branch(module_list, module_f_path, n_branch, modules, c_path):
     """
@@ -821,10 +708,10 @@ def commit_branch(module_list, module_f_path, msg):
         module_path = module_f_path + filename + "/"
         git = RepoGit(module_path)
         branch = git.getCurrentBranch()
-        msg = ''
+        error_msg = ''
         result = 0
         if not git.is_dirty():
-            msg = "很干净，没有可提交的"
+            error_msg = "很干净，没有可提交的"
         else:
             # 判断是否有没有追踪的文件
             untracks = git.untracked()
@@ -832,8 +719,8 @@ def commit_branch(module_list, module_f_path, msg):
             git.commit(msg)
             result = not git.is_dirty()
             if result == 0:
-                msg = "提交失败"
-        modul_branch_model = ModuleStatusModel(module.module, module.pod, result, branch, msg)
+                error_msg = "提交失败"
+        modul_branch_model = ModuleStatusModel(module.module, module.pod, result, branch, error_msg)
         commit_result.append(modul_branch_model)
     return commit_result
 
@@ -1139,7 +1026,6 @@ class yhgit:
                 elif merg_Model.result == 0:
                     fail_list.append(merg_Model)
                 elif merg_Model.result == -1:
-                    error_module = error_module + (merg_Model.module + "\n")
                     error_list.append(merg_Model)
             printTable(success_list, "没有代码要提交的模块")
             printTable(fail_list, "有代码要提交的模块")
@@ -1460,14 +1346,19 @@ def main(argvs=None):
         table = PrettyTable(["编号", "指令", "参数", "说明", "使用"])
         table.add_row(
             [0, "install", "-b 指定分支名; 组件 指定 新建分支的组件",
-             "根据分支branch，然后基于组件或者PodfileLocal.yaml中的配置，新建分支branch", "yhgit install -b test abc \n yhgit install"])
-        table.add_row([1, "status", "", "根据本地PodfileLocal.yaml中配置的仓库，获取所有仓库的开发分支及仓库状态", "yhgit status"])
-        table.add_row([2, "commit", "-m 指定提交的信息", "根据本地PodfileLocal.yaml中配置的仓库，提交本地仓库中的修改", "yhgit commit -m \'提交信息\'"])
+             "根据分支branch，然后基于组件或者PodfileLocal.yaml中的配置，新建分支branch",
+             "yhgit install -b test abc \n yhgit install"])
+        table.add_row(
+            [1, "status", "", "根据本地PodfileLocal.yaml中配置的仓库，获取所有仓库的开发分支及仓库状态", "yhgit status"])
+        table.add_row([2, "commit", "-m 指定提交的信息", "根据本地PodfileLocal.yaml中配置的仓库，提交本地仓库中的修改",
+                       "yhgit commit -m \'提交信息\'"])
         table.add_row([3, "pull", "", "根据本地PodfileLocal.yaml中配置的仓库，拉取远端仓库中代码", "yhgit pull"])
         table.add_row([4, "push", "", "根据本地PodfileLocal.yaml中配置的仓库，推送本地代码到远端", "yhgit push"])
         table.add_row(
-            [5, "merge", "-b 指定分支名; 组件 指定 merge的组件", "然后基于组件merge 分支到当前开发分支，并自动提交", "yhgit merge -b master abc"])
-        table.add_row([6, "release", "组件： 指定组件", "根据本地PodfileModule.yaml中配置的仓库或者手动指定仓库，合并开发分支到master，并自动打新的tag",
+            [5, "merge", "-b 指定分支名; 组件 指定 merge的组件", "然后基于组件merge 分支到当前开发分支，并自动提交",
+             "yhgit merge -b master abc"])
+        table.add_row([6, "release", "组件： 指定组件",
+                       "根据本地PodfileModule.yaml中配置的仓库或者手动指定仓库，合并开发分支到master，并自动打新的tag",
                        "yhgit release abc"])
         table.add_row([7, "clean", "", "清空本地PodfileLocal.yaml 及 modules文件夹", "yhgit clean"])
         table.add_row([8, "version", "", "查看版本号", "yhgit version \n yhgit -v"])
